==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"Wrong calendar" => "Silap kalendar",
"New Timezone:" => "Timezone Baru",
"Timezone changed" => "Zon waktu diubah",
"Invalid request" => "Permintaan tidak sah",
"Calendar" => "Kalendar",
"Birthday" => "Hari lahir",
"Business" => "Perniagaan",
"Call" => "Panggilan",
"Clients" => "Klien",
"Deliverer" => "Penghantar",
"Holidays" => "Cuti",
"Ideas" => "Idea",
"Journey" => "Perjalanan",
"Jubilee" => "Jubli",
"Meeting" => "Perjumpaan",
"Other" => "Lain",
"Personal" => "Peribadi",
"Projects" => "Projek",
"Questions" => "Soalan",
"Work" => "Kerja",
"Does not repeat" => "Tidak berulang",
"Daily" => "Harian",
"Weekly" => "Mingguan",
"Every Weekday" => "Setiap hari minggu",
"Bi-Weekly" => "Dua kali seminggu",
"Monthly" => "Bulanan",
"Yearly" => "Tahunan",
"never" => "jangan",
"by occurrences" => "dari kekerapan",
"by date" => "dari tarikh",
"by monthday" => "dari haribulan",
"by weekday" => "dari hari minggu",
"Monday" => "Isnin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Khamis",
"Friday" => "Jumaat",
"Saturday" => "Sabtu",
"Sunday" => "Ahad",
"events week of month" => "event minggu dari bulan",
"first" => "pertama",
"second" => "kedua",
"third" => "ketiga",
"fourth" => "keempat",
"fifth" => "kelima",
"last" => "akhir",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"by events date" => "dari tarikh event",
"by yearday(s)" => "dari tahun",
"by weeknumber(s)" => "dari nombor minggu",
"by day and month" => "dari hari dan bulan",
"Date" => "Tarikh",
"Cal." => "Kalendar",
"All day" => "Sepanjang hari",
"New Calendar" => "Kalendar baru",
"Missing fields" => "Ruangan tertinggal",
"Title" => "Tajuk",
"From Date" => "Dari tarikh",
"From Time" => "Masa Dari",
"To Date" => "Sehingga kini",
"To Time" => "Semasa",
"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
"Week" => "Minggu",
"Month" => "Bulan",
"List" => "Senarai",
"Today" => "Hari ini",
"Calendars" => "Kalendar",
"There was a fail, while parsing the file." => "Berlaku kegagalan ketika penguraian fail. ",
"Choose active calendars" => "Pilih kalendar yang aktif",
"CalDav Link" => "Pautan CalDav",
"Download" => "Muat turun",
"Edit" => "Edit",
"Delete" => "Hapus",
"New calendar" => "Kalendar baru",
"Edit calendar" => "Edit kalendar",
"Displayname" => "Paparan nama",
"Active" => "Aktif",
"Calendar color" => "Warna kalendar",
"Save" => "Simpan",
"Submit" => "Hantar",
"Cancel" => "Batal",
"Edit an event" => "Edit agenda",
"Export" => "Export",
"Title of the Event" => "Tajuk agenda",
"Category" => "kategori",
"All Day Event" => "Agenda di sepanjang hari ",
"From" => "Dari",
"To" => "ke",
"Advanced options" => "Pilihan maju",
"Location" => "Lokasi",
"Location of the Event" => "Lokasi agenda",
"Description" => "Huraian",
"Description of the Event" => "Huraian agenda",
"Repeat" => "Ulang",
"Advanced" => "Maju",
"Select weekdays" => "Pilih hari minggu",
"Select days" => "Pilih hari",
"and the events day of year." => "dan hari event dalam tahun.",
"and the events day of month." => "dan hari event dalam bulan.",
"Select months" => "Pilih bulan",
"Select weeks" => "Pilih minggu",
"and the events week of year." => "dan event mingguan dalam setahun.",
"Interval" => "Tempoh",
"End" => "Tamat",
"occurrences" => "Peristiwa",
"Import a calendar file" => "Import fail kalendar",
"Please choose the calendar" => "Sila pilih kalendar",
"create a new calendar" => "Cipta kalendar baru",
"Name of new calendar" => "Nama kalendar baru",
"Import" => "Import",
"Importing calendar" => "Import kalendar",
"Calendar imported successfully" => "Kalendar berjaya diimport",
"Close Dialog" => "Tutup dialog",
"Create a new event" => "Buat agenda baru",
"Select category" => "Pilih kategori",
"Timezone" => "Zon waktu",
"Check always for changes of the timezone" => "Sentiasa mengemaskini perubahan zon masa",
"Timeformat" => "Timeformat",
"24h" => "24h",
"12h" => "12h",
"Calendar CalDAV syncing address:" => "Kelendar CalDAV mengemaskini alamat:"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/ms_MY.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Tiada kalendar dijumpai.",
"No events found." => "Tiada agenda dijumpai.",
"Wrong calendar" => "Silap kalendar",
"New Timezone:" => "Timezone Baru",
"Timezone changed" => "Zon waktu diubah",
"Invalid request" => "Permintaan tidak sah",
"Calendar" => "Kalendar",
"Editable" => "Boleh disunting",
"ddd" => "ddd",
"ddd M/d" => "dd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyy",
"Birthday" => "Hari lahir",
"Business" => "Perniagaan",
"Call" => "Panggilan",
"Clients" => "Klien",
"Deliverer" => "Penghantar",
"Holidays" => "Cuti",
"Ideas" => "Idea",
"Journey" => "Perjalanan",
"Jubilee" => "Jubli",
"Meeting" => "Perjumpaan",
"Other" => "Lain",
"Personal" => "Peribadi",
"Projects" => "Projek",
"Questions" => "Soalan",
"Work" => "Kerja",
"unnamed" => "tiada nama",
"New Calendar" => "Kalendar baru",
"Does not repeat" => "Tidak berulang",
"Daily" => "Harian",
"Weekly" => "Mingguan",
"Every Weekday" => "Setiap hari minggu",
"Bi-Weekly" => "Dua kali seminggu",
"Monthly" => "Bulanan",
"Yearly" => "Tahunan",
"never" => "jangan",
"by occurrences" => "dari kekerapan",
"by date" => "dari tarikh",
"by monthday" => "dari haribulan",
"by weekday" => "dari hari minggu",
"Monday" => "Isnin",
"Tuesday" => "Selasa",
"Wednesday" => "Rabu",
"Thursday" => "Khamis",
"Friday" => "Jumaat",
"Saturday" => "Sabtu",
"Sunday" => "Ahad",
"events week of month" => "event minggu dari bulan",
"first" => "pertama",
"second" => "kedua",
"third" => "ketiga",
"fourth" => "keempat",
"fifth" => "kelima",
"last" => "akhir",
"January" => "Januari",
"February" => "Februari",
"March" => "Mac",
"April" => "April",
"May" => "Mei",
"June" => "Jun",
"July" => "Julai",
"August" => "Ogos",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Disember",
"by events date" => "dari tarikh event",
"by yearday(s)" => "dari tahun",
"by weeknumber(s)" => "dari nombor minggu",
"by day and month" => "dari hari dan bulan",
"Date" => "Tarikh",
"Cal." => "Kalendar",
"All day" => "Sepanjang hari",
"Missing fields" => "Ruangan tertinggal",
"Title" => "Tajuk",
"From Date" => "Dari tarikh",
"From Time" => "Masa Dari",
"To Date" => "Sehingga kini",
"To Time" => "Semasa",
"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
"Week" => "Minggu",
"Month" => "Bulan",
"List" => "Senarai",
"Today" => "Hari ini",
"Your calendars" => "Kalendar anda",
"CalDav Link" => "Pautan CalDav",
"Share Calendar" => "Kongsi Kalendar",
"Download" => "Muat turun",
"Edit" => "Edit",
"Delete" => "Hapus",
"shared with you by" => "dikongsi dengan kamu oleh",
"New calendar" => "Kalendar baru",
"Edit calendar" => "Edit kalendar",
"Displayname" => "Paparan nama",
"Active" => "Aktif",
"Calendar color" => "Warna kalendar",
"Save" => "Simpan",
"Submit" => "Hantar",
"Cancel" => "Batal",
"Edit an event" => "Edit agenda",
"Export" => "Export",
"Eventinfo" => "Maklumat agenda",
"Repeating" => "Pengulangan",
"Alarm" => "Penggera",
"Attendees" => "Jemputan",
"Share" => "Berkongsi",
"Title of the Event" => "Tajuk agenda",
"Category" => "kategori",
"Separate categories with commas" => "Asingkan kategori dengan koma",
"Edit categories" => "Sunting Kategori",
"All Day Event" => "Agenda di sepanjang hari ",
"From" => "Dari",
"To" => "ke",
"Advanced options" => "Pilihan maju",
"Location" => "Lokasi",
"Location of the Event" => "Lokasi agenda",
"Description" => "Huraian",
"Description of the Event" => "Huraian agenda",
"Repeat" => "Ulang",
"Advanced" => "Maju",
"Select weekdays" => "Pilih hari minggu",
"Select days" => "Pilih hari",
"and the events day of year." => "dan hari event dalam tahun.",
"and the events day of month." => "dan hari event dalam bulan.",
"Select months" => "Pilih bulan",
"Select weeks" => "Pilih minggu",
"and the events week of year." => "dan event mingguan dalam setahun.",
"Interval" => "Tempoh",
"End" => "Tamat",
"occurrences" => "Peristiwa",
"create a new calendar" => "Cipta kalendar baru",
"Import a calendar file" => "Import fail kalendar",
"Name of new calendar" => "Nama kalendar baru",
"Import" => "Import",
"Close Dialog" => "Tutup dialog",
"Create a new event" => "Buat agenda baru",
"View an event" => "Papar peristiwa",
"No categories selected" => "Tiada kategori dipilih",
"of" => "dari",
"at" => "di",
"Timezone" => "Zon waktu",
"24h" => "24h",
"12h" => "12h"
);
